gint get_browse_nick(gpointer data, gint source, 
		     GdkInputCondition condition);
gint send_browse_nick(gpointer data, gint source, 
		      GdkInputCondition condition);

socket_t* browse_new();
socket_t* browse_search(char* nick);
GtkWidget* create_browse_popup();
void browse_connect_and_start(socket_t* socket);
file_t* file_create_from_browse_response(char* data);
void file_create_from_browse_new(char* data);
void file_insert_browse(file_t *file);
void browse_user_files(char* nick, int max);
user_t* browse_search_nick(char* nick);
void browse_clear_files(user_t* userinfo);
user_t* browse_create_new(char* nick);
GtkWidget* browse_create_page(char* nick);
void browse_update_user(user_t* userinfo);
void browse_update_stats(user_t* stats);
void browse_remove(user_t* userinfo);
file_t* browse_search_file(user_t* info, char* longname);
void browse_do_search(search_pattern_t* search);

gint await_conn_ack3(gpointer data, gint source, 
		     GdkInputCondition condition);
